@@ -1,4 +1,5 @@
 from actionpack.actions.call import Call
+from actionpack.actions.pipeline import Pipeline
 from actionpack.actions.make_request import MakeRequest
 from actionpack.actions.read_bytes import ReadBytes
 from actionpack.actions.read_input import ReadInput
@@ -10,10 +11,10 @@ from actionpack.actions.write_bytes import WriteBytes
 __all__ = [
     'Call',
     'MakeRequest',
+    'Pipeline',
     'ReadBytes',
     'ReadInput',
     'RetryPolicy',
     'Serialization',
     'WriteBytes'
 ]
-
