@@ -1,17 +1,21 @@
-from actionpack import Action
 from io import BytesIO
+from io import StringIO
+
+from actionpack import Action
+from actionpack.action import Name
+from actionpack.action import Outcome
 
 
-class FakeAction(Action):
+class FakeAction(Action[Name, Outcome]):
 
-    result = f'Performing Action.'
+    result = 'Performing Action.'
 
-    def __init__(self, name=None, exception=None):
+    def __init__(self, name: Name = None, exception=None):
         self.name = name
         self.exception = exception
         self.state = {'this': 'state'}
 
-    def instruction(self):
+    def instruction(self) -> str:
         return self.result
 
     def validate(self):
@@ -21,7 +25,7 @@ class FakeAction(Action):
 
 
 class FakeFile:
-    def __init__(self, contents: bytes=bytes(), mode: str=None):
+    def __init__(self, contents: bytes = bytes(), mode: str = None):
         self.buffer = BytesIO(contents)
         self.buffer.read()
         self.mode = mode
@@ -42,4 +46,3 @@ class FakeFile:
 
     def __exit__(self, *args):
         self.closed = True
-
