@@ -1,20 +1,22 @@
 import pickle
 
-from actionpack import Action
+from os import getcwd as cwd
+from unittest import TestCase
+from unittest.mock import patch
+
+from actionpack.action import Result
 from actionpack.actions import WriteBytes
 from actionpack.utils import pickleable
 from tests.actionpack import FakeFile
 
-from unittest import TestCase
-from unittest.mock import patch
-
 
 class WriteBytesTest(TestCase):
 
     def setUp(self):
         self.salutation = 'Hello.'.encode()
         self.question = ' How are you?'.encode()
-        self.action = WriteBytes('valid/path/to/file', self.question)
+        self.absfilepath = f'{cwd()}/valid/path/to/file'
+        self.action = WriteBytes(self.absfilepath, self.question)
 
     @patch('pathlib.Path.open')
     def test_can_WriteBytes(self, mock_output):
@@ -23,17 +25,40 @@ class WriteBytesTest(TestCase):
         result = self.action.perform()
 
         self.assertEqual(file.read(), self.salutation + self.question)
-        self.assertEqual(result.value, len(self.question))
+        self.assertIsInstance(result, Result)
+        self.assertEqual(result.value, self.absfilepath)
 
     @patch('pathlib.Path.open')
     def test_can_overWriteBytes(self, mock_output):
         file = FakeFile(self.salutation, 'wb')
         mock_output.return_value = file
-        action = WriteBytes('valid/path/to/file', self.question, overwrite=True)
         result = self.action.perform()
 
         self.assertEqual(file.read(), self.question)
-        self.assertEqual(result.value, len(self.question))
+        self.assertEqual(result.value, self.absfilepath)
+
+    @patch('pathlib.Path.open')
+    def test_can_WriteBytes_in_append_mode(self, mock_output):
+        file = FakeFile(self.salutation, mode='a')
+        mock_output.return_value = file
+        question = b' How are you?'
+        action = WriteBytes(self.absfilepath, question, append=True)
+        action.perform()
+        action.perform()
+
+        self.assertEqual(
+            self.salutation + question + b'\n' + question + b'\n',
+            file.read()
+        )
+
+    @patch('pathlib.Path.open')
+    def test_cannot_overwrite_and_append(self, mock_output):
+        file = FakeFile(self.salutation)
+        mock_output.return_value = file
+        action = WriteBytes(self.absfilepath, b'bytes to write', overwrite=True, append=True)
+
+        with self.assertRaises(ValueError):
+            action.validate()
 
     def test_can_pickle(self):
         pickled = pickleable(self.action)
@@ -41,4 +66,3 @@ class WriteBytesTest(TestCase):
 
         self.assertTrue(pickleable(self.action))
         self.assertEqual(unpickled.__dict__, self.action.__dict__)
-
