@@ -1,36 +1,52 @@
 import pickle
 
+from functools import reduce
+from threading import Thread
+from unittest import TestCase
+
 from actionpack import Action
+from actionpack.action import Result
 from actionpack.utils import pickleable
 from tests.actionpack import FakeAction
 from tests.actionpack import FakeFile
 from tests.actionpack.actions import FakeWriteBytes
 
-from functools import reduce
-from oslash import Left
-from oslash import Right
-from threading import Thread
-from unittest import TestCase
-from unittest.mock import patch
-
 
 class ActionTest(TestCase):
 
-    def test_Action_produces_Right_result_when_performed(self):
+    def setUp(self) -> None:
+        self.exception = Exception('something went wrong :/')
+
+    def test_Action_produces_Result_result_when_performed(self):
         result = FakeAction().perform()
-        self.assertIsInstance(result, Right)
+        self.assertIsInstance(result, Result)
         self.assertEqual(result.value, FakeAction.result)
 
-    def test_Action_produces_Left_if_exception_raised_when_performed(self):
-        exception = Exception('something went wrong :/')
-        result = FakeAction(exception=exception).perform()
-        self.assertIsInstance(result, Left)
-        self.assertEqual(result.value, exception)
+    def test_Action_produces_Result_if_exception_raised_when_performed(self):
+        result = FakeAction(exception=self.exception).perform()
+        self.assertIsInstance(result, Result)
+        self.assertEqual(result.value, self.exception)
 
     def test_Action_can_raise_exception(self):
-        exception = Exception('This is fine :|')
-        with self.assertRaises(type(exception)):
-            FakeAction(exception=exception).perform(should_raise=True)
+        with self.assertRaises(type(self.exception)):
+            FakeAction(exception=self.exception).perform(should_raise=True)
+
+    def test_can_determine_if_Result_was_successful(self):
+        success = FakeAction().perform()
+        failure = FakeAction(exception=self.exception).perform()
+
+        self.assertTrue(success.successful)
+        self.assertFalse(failure.successful)
+
+    def test_Result_success_is_immutable(self):
+        success = FakeAction().perform()
+        failure = FakeAction(exception=self.exception).perform()
+
+        with self.assertRaises(AttributeError):
+            success.successful = 'nah.'
+
+        with self.assertRaises(AttributeError):
+            failure.successful = 'maybe?'
 
     def test_Action_can_be_serialized(self):
         action = FakeAction()
@@ -72,4 +88,3 @@ class ActionTest(TestCase):
         name2 = 'different name'
         action.name = name2
         self.assertEqual(action.name, name2)
-
